@@ -1,7 +1,7 @@
 // qtractorActionControl.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2017, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -38,7 +38,7 @@ class qtractorActionControl : public QObject
 public:
 
 	// ctor.
-	qtractorActionControl(QObject *pParent = NULL);
+	qtractorActionControl(QObject *pParent = nullptr);
 
 	// dtor.
 	~qtractorActionControl();
