@@ -1,7 +1,7 @@
 // qtractorClip.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -34,15 +34,12 @@
 
 #include <QFileInfo>
 #include <QPainter>
+#include <QPainterPath>
 #include <QPolygon>
 #include <QDir>
 
 #include <QDomDocument>
 
-#ifdef CONFIG_GRADIENT
-#include <QLinearGradient>
-#endif
-
 
 //-------------------------------------------------------------------------
 // qtractorClip -- Track clip capsule.
@@ -144,7 +141,7 @@ QString qtractorClip::shortClipName ( const QString& sClipName ) const
 		const QString& sSessionName = m_pTrack->session()->sessionName();
 		if (!sSessionName.isEmpty()) {
 			const QString sRegExp("^%1[\\-|_|\\s]+");
-			sShortClipName.remove(QRegExp(sRegExp.arg(sSessionName)));
+			sShortClipName.remove(QRegularExpression(sRegExp.arg(sSessionName)));
 		}
 	}
 
@@ -315,8 +312,13 @@ void qtractorClip::updateClipTime (void)
 	m_iClipStart = pSession->frameFromTick(m_iClipStartTime);
 	m_iClipLength = pSession->frameFromTickRange(
 		m_iClipStartTime, m_iClipStartTime + m_iClipLengthTime);
+#if 1// EXPERIMENTAL: Don't quantize to MIDI metronomic time-scale...
+	m_iClipOffsetTime = pSession->tickFromFrameRange(
+		m_iClipStart, m_iClipStart + m_iClipOffset, true);
+#else
 	m_iClipOffset = pSession->frameFromTickRange(
 		m_iClipStartTime, m_iClipStartTime + m_iClipOffsetTime, true);
+#endif
 
 	m_iFadeInLength = pSession->frameFromTickRange(
 		m_iClipStartTime, m_iClipStartTime + m_iFadeInTime);
