@@ -1,7 +1,7 @@
 // qtractorConnectForm.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -44,7 +44,8 @@ class qtractorConnectForm : public QWidget
 public:
 
 	// Constructor.
-	qtractorConnectForm(QWidget *pParent = 0, Qt::WindowFlags wflags = 0);
+	qtractorConnectForm(QWidget *pParent = nullptr,
+		Qt::WindowFlags wflags = Qt::WindowFlags());
 	// Destructor.
 	~qtractorConnectForm();
 
