@@ -440,7 +440,7 @@ static int osc_exiting ( DssiEditor *pDssiEditor )
 
 
 static int osc_message ( const char *path, const char * /*types*/,
-	lo_arg **argv, int /*argc*/, void *data, void * /*user_data*/ )
+	lo_arg **argv, int /*argc*/, lo_message data, void * /*user_data*/ )
 {
 	QMutexLocker locker(&g_oscMutex);
 
