@@ -242,7 +242,7 @@ bool qtractorBusCommand::updateBus (void)
 				}
 			}
 			// Find the MIDI strips that have this (audio) bus monitored...
-			if ((m_pBus->busType() == qtractorTrack::Audio)) {
+			if (m_pBus->busType() == qtractorTrack::Audio && m_iChannels != iChannels) {
 				qtractorAudioBus *pAudioOutputBus
 					= static_cast<qtractorAudioBus *> (m_pBus);
 				const QList<qtractorMixerStrip *>& strips2
@@ -263,11 +263,14 @@ bool qtractorBusCommand::updateBus (void)
 	// Close all applicable tracks...
 	for (qtractorTrack *pTrack = pSession->tracks().first();
 			pTrack; pTrack = pTrack->next()) {
-		if (pTrack->inputBus() == m_pBus)
+		if (pTrack->trackType() != m_pBus->busType())
+			continue;
+		if (pTrack->inputBus()  == m_pBus)
 			pTrack->setInputBusName(m_sBusName);
 		if (pTrack->outputBus() == m_pBus)
 			pTrack->setOutputBusName(m_sBusName);
-		if (pTrack->inputBus() == m_pBus || pTrack->outputBus() == m_pBus) {
+		if (pTrack->inputBus()  == m_pBus ||
+			pTrack->outputBus() == m_pBus) {
 			if (pMixer) {
 				pStrip = (pMixer->trackRack())->findStrip(pTrack->monitor());
 				if (pStrip)
@@ -290,6 +293,7 @@ bool qtractorBusCommand::updateBus (void)
 	m_pBus->setBusName(m_sBusName);
 	m_pBus->setBusMode(m_busMode);
 	m_pBus->setMonitor(m_bMonitor);
+
 	// Special case for typed buses...
 	if (pAudioBus) {
 		pAudioBus->setChannels(m_iChannels);
@@ -317,6 +321,8 @@ bool qtractorBusCommand::updateBus (void)
 	qtractorTracks *pTracks = pMainForm->tracks();
 	for (qtractorTrack *pTrack = pSession->tracks().first();
 			pTrack; pTrack = pTrack->next()) {
+		if (pTrack->trackType() != m_pBus->busType())
+			continue;
 		if (pTrack->inputBusName()  == m_sBusName ||
 			pTrack->outputBusName() == m_sBusName) {
 			// Reopen track back...
@@ -340,9 +346,19 @@ bool qtractorBusCommand::updateBus (void)
 				pStrip->setBus(pStrip->bus());
 		}
 		pMixer->updateBuses();
+		// Update all applicable MIDI managers too...
 		QListIterator<qtractorMidiManager *> iter2(managers);
-		while (iter2.hasNext())
-			iter2.next()->setAudioOutputMonitor(true);
+		while (iter2.hasNext()) {
+			qtractorMidiManager *pMidiManager = iter2.next();
+		//	pMidiManager->setAudioOutputMonitor(true);
+			qtractorPluginList *pPluginList = pMidiManager->pluginList();
+			if (pPluginList) {
+				const bool bAudioOuts
+					= pPluginList->resetChannels(m_iChannels, false);
+				pPluginList->setChannelsEx(m_iChannels);
+				pMidiManager->setAudioOutputMonitorEx(bAudioOuts);
+			}
+		}
 	}
 
 	// Swap saved bus properties...
@@ -429,7 +445,10 @@ bool qtractorBusCommand::deleteBus (void)
 	// Close all applicable tracks...
 	for (qtractorTrack *pTrack = pSession->tracks().first();
 			pTrack; pTrack = pTrack->next()) {
-		if (pTrack->inputBus() == m_pBus || pTrack->outputBus() == m_pBus) {
+		if (pTrack->trackType() != m_pBus->busType())
+			continue;
+		if (pTrack->inputBus()  == m_pBus ||
+			pTrack->outputBus() == m_pBus) {
 			pTrack->close();
 			if (pMixer) {
 				pStrip = (pMixer->trackRack())->findStrip(pTrack->monitor());
