@@ -1,7 +1,7 @@
 // qtractorFiles.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -87,7 +87,7 @@ qtractorFiles::qtractorFiles ( QWidget *pParent )
 	// Player button (initially disabled)...
 	m_pPlayWidget = new QWidget(m_pTabWidget);
 	m_pPlayLayout = new QHBoxLayout(/*m_pPlayWidget*/);
-	m_pPlayLayout->setMargin(2);
+	m_pPlayLayout->setContentsMargins(2, 2, 2, 2);
 	m_pPlayLayout->setSpacing(2);
 	m_pPlayWidget->setLayout(m_pPlayLayout);
 
@@ -153,7 +153,7 @@ qtractorFiles::qtractorFiles ( QWidget *pParent )
 
 	// Prepare the dockable window stuff.
 	QDockWidget::setWidget(m_pTabWidget);
-	QDockWidget::setFeatures(QDockWidget::AllDockWidgetFeatures);
+//	QDockWidget::setFeatures(QDockWidget::AllDockWidgetFeatures);
 	QDockWidget::setAllowedAreas(
 		Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
 	// Some specialties to this kind of dock window...
