@@ -1,7 +1,7 @@
 // qtractorInstrumentForm.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -41,7 +41,7 @@ class qtractorInstrumentForm : public QDialog
 public:
 
 	// Constructor.
-	qtractorInstrumentForm(QWidget *pParent = 0, Qt::WindowFlags wflags = 0);
+	qtractorInstrumentForm(QWidget *pParent = nullptr);
 	// Destructor.
 	~qtractorInstrumentForm();
 
