@@ -253,11 +253,13 @@ void qtractorLadspaPlugin::setChannels ( unsigned short iChannels )
 		
 	// Estimate the (new) number of instances...
 	const unsigned short iOldInstances = instances();
-	const unsigned short iInstances
-		= pLadspaType->instances(iChannels, list()->isMidi());
-	// Now see if instance count changed anyhow...
-	if (iInstances == iOldInstances && iChannels == channels())
-		return;
+	unsigned short iInstances = 0;
+	if (iChannels > 0) {
+		iInstances = pLadspaType->instances(iChannels, list()->isMidi());
+		// Now see if instance count changed anyhow...
+		if (iInstances == iOldInstances && iChannels == channels())
+			return;
+	}
 
 	const LADSPA_Descriptor *pLadspaDescriptor
 		= pLadspaType->ladspa_descriptor();
