@@ -1,7 +1,7 @@
 // qtractorMidiEditor.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2021, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -335,6 +335,11 @@ public:
 	void setSyncViewHold(bool bSyncViewHold);
 	bool isSyncViewHold() const;
 
+	// Return either snapped pixel/frame,
+	// or the passed one if [Alt] key is pressed.
+	unsigned int pixelSnap(unsigned int x) const;
+	unsigned long frameSnap(unsigned long iFrame) const;
+
 	// Make given frame position visible in view.
 	void ensureVisibleFrame(qtractorScrollView *pScrollView, unsigned long iFrame);
 
