@@ -1,7 +1,7 @@
 // qtractorMidiEventList.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -864,7 +864,7 @@ qtractorMidiEventList::qtractorMidiEventList ( QWidget *pParent )
 
 	// Prepare the dockable window stuff.
 	QDockWidget::setWidget(m_pListView);
-	QDockWidget::setFeatures(QDockWidget::AllDockWidgetFeatures);
+//	QDockWidget::setFeatures(QDockWidget::AllDockWidgetFeatures);
 	QDockWidget::setAllowedAreas(
 		Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
 	// Some specialties to this kind of dock window...
