@@ -1,7 +1,7 @@
 // qtractorMidiSequence.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -56,6 +56,8 @@ qtractorMidiSequence::~qtractorMidiSequence (void)
 // Sequencer reset method.
 void qtractorMidiSequence::clear (void)
 {
+	m_iBankSelMethod = -1;
+
 	m_iBank = -1;
 	m_iProg = -1;
 
@@ -81,7 +83,7 @@ void qtractorMidiSequence::addEvent ( qtractorMidiEvent *pEvent )
 		NoteMap::Iterator iter = m_notes.find(note);
 		const NoteMap::Iterator& iter_end = m_notes.end();
 		NoteMap::Iterator iter_last;
-		qtractorMidiEvent *pNoteEvent = NULL;
+		qtractorMidiEvent *pNoteEvent = nullptr;
 		for ( ; iter != iter_end && iter.key() == note; ++iter) {
 			pNoteEvent = iter.value();
 			iter_last = iter;
@@ -195,6 +197,11 @@ void qtractorMidiSequence::replaceEvents ( qtractorMidiSequence *pSeq,
 		iTimeLength = pSeq->timeLength();
 	}
 
+	// Reset bank/prog settings anyway...
+	setBankSelMethod(pSeq->bankSelMethod());
+	setBank(pSeq->bank());
+	setProg(pSeq->prog());
+
 	// Set the given replacement range...
 	const unsigned short iTicksPerBeat
 		= pSeq->ticksPerBeat();
@@ -207,7 +214,7 @@ void qtractorMidiSequence::replaceEvents ( qtractorMidiSequence *pSeq,
 	qtractorMidiEvent *pEvent = m_events.first();
 	while (pEvent) {
 		qtractorMidiEvent *pNextEvent = pEvent->next();
-		if (pEvent->time() >= iTimeStart &&	pEvent->time() < iTimeEnd)
+		if (pEvent->time() >= iTimeStart && pEvent->time() < iTimeEnd)
 			removeEvent(pEvent);
 		pEvent = pNextEvent;
 	}
