@@ -1,7 +1,7 @@
 // qtractorObserverWidget.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -29,8 +29,9 @@
 // class qtractorObserverWidget -- Template widget observer/visitor.
 //
 
+#include "qtractorSpinBox.h"
+
 #include <QCheckBox>
-#include <QSpinBox>
 #include <QSlider>
 
 
@@ -148,7 +149,7 @@ signals:
 // class qtractorObserverSpinBox -- Concrete widget observer.
 //
 
-class qtractorObserverSpinBox : public qtractorObserverWidget<QDoubleSpinBox>
+class qtractorObserverSpinBox : public qtractorObserverWidget<qtractorSpinBox>
 {
 	Q_OBJECT
 
