@@ -1,7 +1,7 @@
 // qtractorOptions.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2021, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -141,11 +141,15 @@ public:
 	bool bMidiControlBus;
 	bool bMidiMetroBus;
 	bool bMidiMetronome;
+	int  iMidiMetroOffset;
 	int  iMidiMmcDevice;
 	int  iMidiMmcMode;
 	int  iMidiSppMode;
 	int  iMidiClockMode;
 
+	// Whether to reset all MIDI controllers (on playback start).
+	bool bMidiResetAllControllers;
+
 	// MIDI Metronome parameters.
 	int iMetroChannel;
 	int iMetroBarNote;
@@ -155,9 +159,6 @@ public:
 	int iMetroBeatVelocity;
 	int iMetroBeatDuration;
 
-	// MIDI metronome latency offset compensation.
-	int iMidiMetroOffset;
-
 	// Default options...
 	QString sSessionDir;
 	QString sAudioDir;
