@@ -1,7 +1,7 @@
 // qtractorPasteRepeatForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -34,9 +34,8 @@
 // qtractorPasteRepeatForm -- UI wrapper form.
 
 // Constructor.
-qtractorPasteRepeatForm::qtractorPasteRepeatForm (
-	QWidget *pParent, Qt::WindowFlags wflags )
-	: QDialog(pParent, wflags)
+qtractorPasteRepeatForm::qtractorPasteRepeatForm ( QWidget *pParent )
+	: QDialog(pParent)
 {
 	// Setup UI struct...
 	m_ui.setupUi(this);
