@@ -1,7 +1,7 @@
 // qtractorPasteRepeatForm.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -39,7 +39,7 @@ class qtractorPasteRepeatForm : public QDialog
 public:
 
 	// Constructor.
-	qtractorPasteRepeatForm(QWidget *pParent = 0, Qt::WindowFlags wflags = 0);
+	qtractorPasteRepeatForm(QWidget *pParent = nullptr);
 	// Destructor.
 	~qtractorPasteRepeatForm();
 
