@@ -71,7 +71,7 @@ const WindowFlags WindowCloseButtonHint = WindowFlags(0x08000000);
 bool qtractorPluginFile::open (void)
 {
 	// Check whether already open...
-	if (m_module && ++m_iOpenCount > 1)
+	if (m_module || ++m_iOpenCount > 1)
 		return true;
 
 	// Do the opening dance...
@@ -87,10 +87,7 @@ bool qtractorPluginFile::open (void)
 
 void qtractorPluginFile::close (void)
 {
-	if (!m_module)
-		return;
-
-	if (--m_iOpenCount > 0)
+	if (!m_module || --m_iOpenCount > 0)
 		return;
 
 	// ATTN: Might be really needed, as it would
@@ -302,11 +299,11 @@ void qtractorPlugin::setInstances ( unsigned short iInstances )
 // Activation methods.
 
 // immediate
-void qtractorPlugin::setActivated (bool bActivated)
+void qtractorPlugin::setActivated ( bool bActivated )
 {
 	updateActivated(bActivated);
 
-	m_activateObserver.setValue(bActivated ? 1.0f : 0.0f);
+	setActivatedEx(bActivated);
 }
 
 // queued (GUI invocation)
@@ -410,6 +407,17 @@ void qtractorPlugin::updateActivatedEx ( bool bActivated )
 }
 
 
+// Internal activation methods.
+void qtractorPlugin::setChannelsActivated (
+	unsigned short iChannels, bool bActivated )
+{
+	if (iChannels > 0)
+		setActivated(bActivated);
+	else
+		updateActivated(false);
+}
+
+
 // Activate observer ctor.
 qtractorPlugin::ActivateObserver::ActivateObserver ( qtractorPlugin *pPlugin )
 	: qtractorMidiControlObserver(pPlugin->activateSubject()), m_pPlugin(pPlugin)
@@ -1807,11 +1815,11 @@ void qtractorPluginList::setChannelsEx ( unsigned short iChannels )
 		if (pSession)
 			pAudioEngine = pSession->audioEngine();
 		if (pAudioEngine) {
-			const unsigned int iBufferSize = pAudioEngine->bufferSize();
+			const unsigned int iBufferSizeEx = pAudioEngine->bufferSizeEx();
 			m_pppBuffers[1] = new float * [m_iChannels];
 			for (unsigned short i = 0; i < m_iChannels; ++i) {
-				m_pppBuffers[1][i] = new float [iBufferSize];
-				::memset(m_pppBuffers[1][i], 0, iBufferSize * sizeof(float));
+				m_pppBuffers[1][i] = new float [iBufferSizeEx];
+				::memset(m_pppBuffers[1][i], 0, iBufferSizeEx * sizeof(float));
 			}
 		}	// Gone terribly wrong...
 		else m_iChannels = 0;
@@ -1859,7 +1867,7 @@ void qtractorPluginList::resetBuffers (void)
 	if (pAudioEngine == nullptr)
 		return;
 
-	const unsigned int iBufferSize = pAudioEngine->bufferSize();
+	const unsigned int iBufferSizeEx = pAudioEngine->bufferSizeEx();
 
 #if 0
 	// Save and reset activation count...
@@ -1876,7 +1884,7 @@ void qtractorPluginList::resetBuffers (void)
 	// Reset interim buffer, if any...
 	if (m_pppBuffers[1]) {
 		for (unsigned short i = 0; i < m_iChannels; ++i)
-			::memset(m_pppBuffers[1][i], 0, iBufferSize * sizeof(float));
+			::memset(m_pppBuffers[1][i], 0, iBufferSizeEx * sizeof(float));
 	}
 #if 0
 	// Restore activation of all previously deactivated plugins...
