@@ -1,7 +1,7 @@
 // qtractorSessionForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2021, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -34,7 +34,7 @@
 #include <QValidator>
 #include <QLineEdit>
 
-#include <math.h>
+#include <cmath>
 
 
 //----------------------------------------------------------------------------
@@ -57,6 +57,12 @@ qtractorSessionForm::qtractorSessionForm ( QWidget *pParent )
 		pOptions->loadComboBoxHistory(m_ui.SessionDirComboBox);
 	}
 
+	const QFont& font = QDialog::font();
+	const QFont font2(font.family(), font.pointSize() - 2);
+	m_ui.AutoSessionDirCheckBox->setFont(font2);
+	m_ui.AutoSessionDirCheckBox->setMaximumHeight(
+		QFontMetrics(font2).height());
+
 #if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
 	m_ui.SessionDirComboBox->lineEdit()->setClearButtonEnabled(true);
 #endif
