@@ -1,7 +1,7 @@
 // qtractorTakeRangeForm.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -40,7 +40,7 @@ class qtractorTakeRangeForm : public QDialog
 public:
 
 	// Constructor.
-	qtractorTakeRangeForm(QWidget *pParent = 0, Qt::WindowFlags wflags = 0);
+	qtractorTakeRangeForm(QWidget *pParent = nullptr);
 	// Destructor.
 	~qtractorTakeRangeForm();
 
