@@ -1,7 +1,7 @@
 // qtractorTimeScaleCommand.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -80,9 +80,13 @@ bool qtractorTimeScaleNodeCommand::addNode (void)
 
 	// If currently playing, we need to do a stop and go...
 	const bool bPlaying = pSession->isPlaying();
+	const unsigned long iPlayHead = pSession->playHead();
 
 	pSession->lock();
 
+	if (bPlaying)
+		pSession->seek(0, false);
+
 	const float fOldTempo = pNode->tempo;
 	const float fNewTempo = m_fTempo;
 
@@ -127,6 +131,8 @@ bool qtractorTimeScaleNodeCommand::addNode (void)
 		// The MIDI engine queue needs a reset...
 		if (pSession->midiEngine())
 			pSession->midiEngine()->resetTempo();
+		// Resync all clips on play-head...
+		pSession->seek(iPlayHead, true);
 	} else {
 		// Force JACK Timebase state, if applicable...
 		if (pSession->audioEngine())
@@ -155,9 +161,13 @@ bool qtractorTimeScaleNodeCommand::updateNode (void)
 
 	// If currently playing, we need to do a stop and go...
 	const bool bPlaying = pSession->isPlaying();
+	const unsigned long iPlayHead = pSession->playHead();
 
 	pSession->lock();
 
+	if (bPlaying)
+		pSession->seek(0, false);
+
 	const float          fTempo       = pNode->tempo;
 	const unsigned short iBeatType    = pNode->beatType;
 	const unsigned short iBeatsPerBar = pNode->beatsPerBar;
@@ -216,6 +226,8 @@ bool qtractorTimeScaleNodeCommand::updateNode (void)
 		// The MIDI engine queue needs a reset...
 		if (pSession->midiEngine())
 			pSession->midiEngine()->resetTempo();
+		// Resync all clips on play-head...
+		pSession->seek(iPlayHead, true);
 	} else {
 		// Force JACK Timebase state, if applicable...
 		if (pSession->audioEngine())
@@ -244,9 +256,13 @@ bool qtractorTimeScaleNodeCommand::removeNode (void)
 
 	// If currently playing, we need to do a stop and go...
 	const bool bPlaying = pSession->isPlaying();
+	const unsigned long iPlayHead = pSession->playHead();
 
 	pSession->lock();
 
+	if (bPlaying)
+		pSession->seek(0, false);
+
 	qtractorTimeScale::Node *pPrev = pNode->prev();
 	const float fOldTempo = pNode->tempo;
 	const float fNewTempo = (pPrev ? pPrev->tempo : m_pTimeScale->tempo());
@@ -296,6 +312,8 @@ bool qtractorTimeScaleNodeCommand::removeNode (void)
 		// The MIDI engine queue needs a reset...
 		if (pSession->midiEngine())
 			pSession->midiEngine()->resetTempo();
+		// Resync all clips on play-head...
+		pSession->seek(iPlayHead, true);
 	} else {
 		// Force JACK Timebase state, if applicable...
 		if (pSession->audioEngine())
