@@ -1,7 +1,7 @@
 // qtractorTrack.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2021, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -153,6 +153,14 @@ public:
 	void setMidiNoteMax(unsigned char note);
 	unsigned char midiNoteMax() const;
 
+	// MIDI specific volume controller.
+	void setMidiVolume(unsigned char vol, bool bUpdate = false);
+	unsigned char midiVolume() const;
+
+	// MIDI specific panning controller.
+	void setMidiPanning(unsigned char pan, bool bUpdate = false);
+	unsigned char midiPanning() const;
+
 	// Assigned bus name accessors.
 	void setInputBusName(const QString& sBusName);
 	const QString& inputBusName() const;
@@ -384,6 +392,9 @@ private:
 	unsigned char    m_midiNoteMax; // MIDI specific: track-maximum note;
 	unsigned char    m_midiNoteMin; // MIDI specific: track-minimum note.
 
+	unsigned char    m_midiVolume;  // MIDI specific: track-volume;
+	unsigned char    m_midiPanning; // MIDI specific: track-panning.
+
 	int              m_iHeight;     // View height (normalized).
 	int              m_iHeightBase; // View height (base).
 	int              m_iZoomHeight; // View height (zoomed).
