@@ -253,6 +253,11 @@ public:
 	void setSyncViewHold(bool bSyncViewHold);
 	bool isSyncViewHold() const;
 
+	// Return either the snapped pixel/frame,
+	// or the passed one if [Alt] key is pressed.
+	unsigned int pixelSnap(unsigned int x) const;
+	unsigned long frameSnap(unsigned long iFrame) const;
+
 protected:
 
 	// Resize event handler.
