@@ -1,7 +1,7 @@
 // qtractor_plugin_scan.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2021, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -1265,7 +1265,8 @@ bool qtractor_vst3_scan::open_descriptor ( unsigned long iIndex )
 
 	Vst::IEditController *controller = m_pImpl->controller();
 	if (controller) {
-		IPtr<IPlugView> editor = controller->createView(Vst::ViewType::kEditor);
+		IPtr<IPlugView> editor
+			= owned(controller->createView(Vst::ViewType::kEditor));
 		m_bEditor = (editor != nullptr);
 	}
 
